@@ -1,5 +1,5 @@
 "emp.qtscore" <-
-function(formula,data,snpsubset,idsubset,strata,trait.type,times=100,quiet=FALSE,bcast=10) {
+function(formula,data,snpsubset,idsubset,strata,trait.type="gaussian",times=100,quiet=FALSE,bcast=10) {
 	out <- qtscore(formula=formula,data=data,snpsubset=snpsubset,idsubset=idsubset,strata=strata,
 			trait.type=trait.type,times=times,quiet=quiet,bcast=bcast)
 	out
